package com.fjhx.rabbitmq;

import com.alibaba.fastjson.JSONObject;
import com.fjhx.rfid.r2000.common.service.IRFIDService;
import com.rabbitmq.client.Channel;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.listener.api.ChannelAwareMessageListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.retry.annotation.Backoff;
import org.springframework.retry.annotation.EnableRetry;
import org.springframework.retry.annotation.Retryable;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;

/**
 * rabbitmq队列监听工具
 */
@EnableRetry
@Component
public class JsRabbitMQListener implements ChannelAwareMessageListener {

    @Autowired
    private IRFIDService rfidService;

    @RabbitHandler
    @RabbitListener(
            queues = {
                    "instructions_queue"
            }
    )
    @Retryable(value = {Exception.class}, backoff = @Backoff(delay = 3000, multiplier = 1))
    @Override
    public void onMessage(Message message, Channel channel) throws Exception {


        try {
            String msg = new String(message.getBody(), StandardCharsets.UTF_8);

            JSONObject jsonObject = JSONObject.parseObject(msg);

            rfidService.receiveInstructions(jsonObject);

            // 手动签收消息,通知mq服务器端删除该消息
            channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
        } catch (Exception e) {
            e.printStackTrace();
            // 丢弃该消息
            channel.basicNack(message.getMessageProperties().getDeliveryTag(), false, false);
            throw e;
        }
    }

}

