package com.fjhx.rfid.r2000.common.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.fjhx.config.RFIDConfig;
import com.fjhx.constant.RFIDConstant;
import com.fjhx.rfid.r2000.common.service.IRFIDService;
import com.fjhx.rfid.r2000.tcp.service.TcpServiceV2;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @Description:
 * @ClassName: TcpServiceImpl
 * @Author: linqt
 * @Date: 2022/3/17 10:32
 * @Version: 1.0
 */
@Service
public class RFIDServiceImpl implements IRFIDService {


    @Autowired
    private TcpServiceV2 tcpServiceV2;

    /**
     * 接收指令
     *
     * @param jsonObject 参数
     */
    @Override
    public void receiveInstructions(JSONObject jsonObject) {
        System.err.println(jsonObject.toJSONString());

        //处理读写器ip地址
        List<String> tcpIps = RFIDConfig.getTcp().getIps();
        List<String> updIps = RFIDConfig.getUdp().getIps();
        List<String> ips = new ArrayList<>();
        Object o = jsonObject.get("ips");
        if (ObjectUtils.isNotEmpty(o)) {
            ips = JSONObject.parseArray(jsonObject.getString("ips"), String.class);
        }
        System.err.println("ips--：" + ips.toString());

        if (CollectionUtils.isNotEmpty(ips)) {
            List<String> finalTcpIps = tcpIps;
            tcpIps = ips.stream()
                    .filter(item -> new ArrayList<>(finalTcpIps).contains(item))
                    .collect(Collectors.toList());

            List<String> finalUpdIps = updIps;
            updIps = ips.stream()
                    .filter(item -> new ArrayList<>(finalUpdIps).contains(item))
                    .collect(Collectors.toList());
        }

        System.err.println("tcpIps--：" + tcpIps.toString());
        System.err.println("updIps--：" + updIps.toString());

        //业务唯一标识
        String busUuid = jsonObject.getString("busUuid");

        //业务服务端用户userId
        String userId = jsonObject.getString("userId");

        //指令类型
        Integer instructType = jsonObject.getInteger("instructType");
        if (Objects.equals(instructType, RFIDConstant.InstructType.INSTRUCT_TYPE_1)) {
            //启动读写器并返回所有数据
            tcpServiceV2.openAndReturnAllData(tcpIps, busUuid, userId);
        } else if (Objects.equals(instructType, RFIDConstant.InstructType.INSTRUCT_TYPE_2)) {
            //启动读写器并返回去重数据
            tcpServiceV2.openAndReturnGoHeavyData(tcpIps, busUuid, userId);
        } else if (Objects.equals(instructType, RFIDConstant.InstructType.INSTRUCT_TYPE_3)) {
            //关闭读写器

        }
    }

}
